/* -*- mode: C; c-file-style: "linux" -*- */

/* MemProf -- memory profiler and leak detector
 * Copyright 1999, 2000, 2001, Red Hat, Inc.
 * Copyright 2002, Kristian Rietveld
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/*====*/

#include "leakdetect.h"
#include "process.h"
#include "profile.h"
#include "server.h"

typedef struct _ProcessWindow ProcessWindow;

struct _ProcessWindow {
   MPProcess *process;
   Profile *profile;
   GSList *leaks;
   
   GtkWidget *main_window;
   GtkWidget *main_notebook;
   GtkWidget *n_allocations_label;
   GtkWidget *bytes_per_label;
   GtkWidget *total_bytes_label;
   
   GtkWidget *profile_func_clist;
   GtkWidget *profile_caller_clist;
   GtkWidget *profile_child_clist;
   
   GtkWidget *leak_block_clist;
   GtkWidget *leak_stack_clist;
   
   GtkWidget *usage_max_label;
   GtkWidget *usage_canvas;
   
   guint usage_max;
   guint usage_high;
   guint usage_leaked;
   
   GnomeCanvasItem *usage_frame;
   GnomeCanvasItem *usage_current_bar;
   GnomeCanvasItem *usage_high_bar;
   GnomeCanvasItem *usage_leak_bar;
   
   guint status_update_timeout;
   
   gboolean follow_fork : 1;
   gboolean follow_exec : 1;
   
   void *detailwin_data;
};


void tree_window_show   (void);
void tree_window_add    (ProcessWindow *window);
void tree_window_remove (ProcessWindow *window);

MPProcess * process_window_get_process  (ProcessWindow *pwin);
gboolean    process_window_visible      (ProcessWindow *pwin);
MPProcess * process_window_get_process  (ProcessWindow *pwin);
void        process_window_show         (ProcessWindow *pwin);
void        process_window_hide         (ProcessWindow *pwin);

void        process_window_maybe_kill   (ProcessWindow *pwin);
void        process_window_maybe_detach (ProcessWindow *pwin);

gboolean hide_and_check_quit (GtkWidget *window);
void     check_quit          (void);

void dw_init(ProcessWindow *pwin);
void dw_shutdown(ProcessWindow *pwin);
void dw_update(ProcessWindow *pwin);
    
